You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2023/12/21 17:04:14 UTC

(camel) branch main updated: Regen due to debezium upgrade

This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/camel.git


The following commit(s) were added to refs/heads/main by this push:
     new 662e84622c8 Regen due to debezium upgrade
662e84622c8 is described below

commit 662e84622c8ef995c78e11b00c416f32b2d4cae8
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Thu Dec 21 18:03:57 2023 +0100

    Regen due to debezium upgrade
---
 .../dsl/DebeziumDb2ComponentBuilderFactory.java    | 38 +++++++++++
 .../DebeziumMongodbComponentBuilderFactory.java    | 46 +++++++++++--
 .../dsl/DebeziumMysqlComponentBuilderFactory.java  | 66 +++++++++++++++++--
 .../dsl/DebeziumOracleComponentBuilderFactory.java | 38 +++++++++++
 .../DebeziumPostgresComponentBuilderFactory.java   | 38 +++++++++++
 .../DebeziumSqlserverComponentBuilderFactory.java  | 38 +++++++++++
 .../dsl/CloudtrailEndpointBuilderFactory.java      | 77 ++++++++++++++++++++++
 .../dsl/DebeziumDb2EndpointBuilderFactory.java     | 35 ++++++++++
 .../dsl/DebeziumMongodbEndpointBuilderFactory.java | 44 +++++++++++--
 .../dsl/DebeziumMySqlEndpointBuilderFactory.java   | 74 ++++++++++++++++++---
 .../dsl/DebeziumOracleEndpointBuilderFactory.java  | 36 ++++++++++
 .../DebeziumPostgresEndpointBuilderFactory.java    | 36 ++++++++++
 .../DebeziumSqlserverEndpointBuilderFactory.java   | 36 ++++++++++
 13 files changed, 579 insertions(+), 23 deletions(-)

diff --git a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumDb2ComponentBuilderFactory.java b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumDb2ComponentBuilderFactory.java
index e9f5b745492..eb8d35c8c3e 100644
--- a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumDb2ComponentBuilderFactory.java
+++ b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumDb2ComponentBuilderFactory.java
@@ -618,6 +618,26 @@ public interface DebeziumDb2ComponentBuilderFactory {
             doSetProperty("incrementalSnapshotChunkSize", incrementalSnapshotChunkSize);
             return this;
         }
+        /**
+         * Specify the strategy used for watermarking during an incremental
+         * snapshot: 'insert_insert' both open and close signal is written into
+         * signal data collection (default); 'insert_delete' only open signal is
+         * written on signal data collection, the close will delete the relative
+         * open signal;.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Default: INSERT_INSERT
+         * Group: db2
+         * 
+         * @param incrementalSnapshotWatermarkingStrategy the value to set
+         * @return the dsl builder
+         */
+        default DebeziumDb2ComponentBuilder incrementalSnapshotWatermarkingStrategy(
+                java.lang.String incrementalSnapshotWatermarkingStrategy) {
+            doSetProperty("incrementalSnapshotWatermarkingStrategy", incrementalSnapshotWatermarkingStrategy);
+            return this;
+        }
         /**
          * Maximum size of each batch of source records. Defaults to 2048.
          * 
@@ -738,6 +758,22 @@ public interface DebeziumDb2ComponentBuilderFactory {
             doSetProperty("pollIntervalMs", pollIntervalMs);
             return this;
         }
+        /**
+         * Optional list of post processors. The processors are defined using
+         * '.type' config option and configured using options ''.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: db2
+         * 
+         * @param postProcessors the value to set
+         * @return the dsl builder
+         */
+        default DebeziumDb2ComponentBuilder postProcessors(
+                java.lang.String postProcessors) {
+            doSetProperty("postProcessors", postProcessors);
+            return this;
+        }
         /**
          * Enables transaction metadata extraction together with event counting.
          * 
@@ -1307,6 +1343,7 @@ public interface DebeziumDb2ComponentBuilderFactory {
             case "heartbeatTopicsPrefix": getOrCreateConfiguration((DebeziumDb2Component) component).setHeartbeatTopicsPrefix((java.lang.String) value); return true;
             case "includeSchemaChanges": getOrCreateConfiguration((DebeziumDb2Component) component).setIncludeSchemaChanges((boolean) value); return true;
             case "incrementalSnapshotChunkSize": getOrCreateConfiguration((DebeziumDb2Component) component).setIncrementalSnapshotChunkSize((int) value); return true;
+            case "incrementalSnapshotWatermarkingStrategy": getOrCreateConfiguration((DebeziumDb2Component) component).setIncrementalSnapshotWatermarkingStrategy((java.lang.String) value); return true;
             case "maxBatchSize": getOrCreateConfiguration((DebeziumDb2Component) component).setMaxBatchSize((int) value); return true;
             case "maxQueueSize": getOrCreateConfiguration((DebeziumDb2Component) component).setMaxQueueSize((int) value); return true;
             case "maxQueueSizeInBytes": getOrCreateConfiguration((DebeziumDb2Component) component).setMaxQueueSizeInBytes((long) value); return true;
@@ -1314,6 +1351,7 @@ public interface DebeziumDb2ComponentBuilderFactory {
             case "notificationEnabledChannels": getOrCreateConfiguration((DebeziumDb2Component) component).setNotificationEnabledChannels((java.lang.String) value); return true;
             case "notificationSinkTopicName": getOrCreateConfiguration((DebeziumDb2Component) component).setNotificationSinkTopicName((java.lang.String) value); return true;
             case "pollIntervalMs": getOrCreateConfiguration((DebeziumDb2Component) component).setPollIntervalMs((long) value); return true;
+            case "postProcessors": getOrCreateConfiguration((DebeziumDb2Component) component).setPostProcessors((java.lang.String) value); return true;
             case "provideTransactionMetadata": getOrCreateConfiguration((DebeziumDb2Component) component).setProvideTransactionMetadata((boolean) value); return true;
             case "queryFetchSize": getOrCreateConfiguration((DebeziumDb2Component) component).setQueryFetchSize((int) value); return true;
             case "retriableRestartConnectorWaitMs": getOrCreateConfiguration((DebeziumDb2Component) component).setRetriableRestartConnectorWaitMs((long) value); return true;
diff --git a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumMongodbComponentBuilderFactory.java b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumMongodbComponentBuilderFactory.java
index e4d6b03442d..cd215f2113f 100644
--- a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumMongodbComponentBuilderFactory.java
+++ b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumMongodbComponentBuilderFactory.java
@@ -547,6 +547,26 @@ public interface DebeziumMongodbComponentBuilderFactory {
             doSetProperty("heartbeatTopicsPrefix", heartbeatTopicsPrefix);
             return this;
         }
+        /**
+         * Specify the strategy used for watermarking during an incremental
+         * snapshot: 'insert_insert' both open and close signal is written into
+         * signal data collection (default); 'insert_delete' only open signal is
+         * written on signal data collection, the close will delete the relative
+         * open signal;.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Default: INSERT_INSERT
+         * Group: mongodb
+         * 
+         * @param incrementalSnapshotWatermarkingStrategy the value to set
+         * @return the dsl builder
+         */
+        default DebeziumMongodbComponentBuilder incrementalSnapshotWatermarkingStrategy(
+                java.lang.String incrementalSnapshotWatermarkingStrategy) {
+            doSetProperty("incrementalSnapshotWatermarkingStrategy", incrementalSnapshotWatermarkingStrategy);
+            return this;
+        }
         /**
          * Maximum size of each batch of source records. Defaults to 2048.
          * 
@@ -615,13 +635,13 @@ public interface DebeziumMongodbComponentBuilderFactory {
         }
         /**
          * The method used to connect to MongoDB cluster. Options include:
-         * 'replica_set' (the default) to individually connect to each replica
-         * set / shard 'sharded' to connect via single connection obtained from
-         * connection string.
+         * 'replica_set' to individually connect to each replica set / shard
+         * 'sharded' (the default) to connect via single connection obtained
+         * from connection string.
          * 
          * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
          * 
-         * Default: replica_set
+         * Default: sharded
          * Group: mongodb
          * 
          * @param mongodbConnectionMode the value to set
@@ -842,6 +862,22 @@ public interface DebeziumMongodbComponentBuilderFactory {
             doSetProperty("pollIntervalMs", pollIntervalMs);
             return this;
         }
+        /**
+         * Optional list of post processors. The processors are defined using
+         * '.type' config option and configured using options ''.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: mongodb
+         * 
+         * @param postProcessors the value to set
+         * @return the dsl builder
+         */
+        default DebeziumMongodbComponentBuilder postProcessors(
+                java.lang.String postProcessors) {
+            doSetProperty("postProcessors", postProcessors);
+            return this;
+        }
         /**
          * Enables transaction metadata extraction together with event counting.
          * 
@@ -1233,6 +1269,7 @@ public interface DebeziumMongodbComponentBuilderFactory {
             case "fieldRenames": getOrCreateConfiguration((DebeziumMongodbComponent) component).setFieldRenames((java.lang.String) value); return true;
             case "heartbeatIntervalMs": getOrCreateConfiguration((DebeziumMongodbComponent) component).setHeartbeatIntervalMs((int) value); return true;
             case "heartbeatTopicsPrefix": getOrCreateConfiguration((DebeziumMongodbComponent) component).setHeartbeatTopicsPrefix((java.lang.String) value); return true;
+            case "incrementalSnapshotWatermarkingStrategy": getOrCreateConfiguration((DebeziumMongodbComponent) component).setIncrementalSnapshotWatermarkingStrategy((java.lang.String) value); return true;
             case "maxBatchSize": getOrCreateConfiguration((DebeziumMongodbComponent) component).setMaxBatchSize((int) value); return true;
             case "maxQueueSize": getOrCreateConfiguration((DebeziumMongodbComponent) component).setMaxQueueSize((int) value); return true;
             case "maxQueueSizeInBytes": getOrCreateConfiguration((DebeziumMongodbComponent) component).setMaxQueueSizeInBytes((long) value); return true;
@@ -1251,6 +1288,7 @@ public interface DebeziumMongodbComponentBuilderFactory {
             case "notificationEnabledChannels": getOrCreateConfiguration((DebeziumMongodbComponent) component).setNotificationEnabledChannels((java.lang.String) value); return true;
             case "notificationSinkTopicName": getOrCreateConfiguration((DebeziumMongodbComponent) component).setNotificationSinkTopicName((java.lang.String) value); return true;
             case "pollIntervalMs": getOrCreateConfiguration((DebeziumMongodbComponent) component).setPollIntervalMs((long) value); return true;
+            case "postProcessors": getOrCreateConfiguration((DebeziumMongodbComponent) component).setPostProcessors((java.lang.String) value); return true;
             case "provideTransactionMetadata": getOrCreateConfiguration((DebeziumMongodbComponent) component).setProvideTransactionMetadata((boolean) value); return true;
             case "queryFetchSize": getOrCreateConfiguration((DebeziumMongodbComponent) component).setQueryFetchSize((int) value); return true;
             case "retriableRestartConnectorWaitMs": getOrCreateConfiguration((DebeziumMongodbComponent) component).setRetriableRestartConnectorWaitMs((long) value); return true;
diff --git a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumOracleComponentBuilderFactory.java b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumOracleComponentBuilderFactory.java
index 283ceb7edc2..8e1f7b891e7 100644
--- a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumOracleComponentBuilderFactory.java
+++ b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumOracleComponentBuilderFactory.java
@@ -724,6 +724,26 @@ public interface DebeziumOracleComponentBuilderFactory {
             doSetProperty("includeSchemaComments", includeSchemaComments);
             return this;
         }
+        /**
+         * Specify the strategy used for watermarking during an incremental
+         * snapshot: 'insert_insert' both open and close signal is written into
+         * signal data collection (default); 'insert_delete' only open signal is
+         * written on signal data collection, the close will delete the relative
+         * open signal;.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Default: INSERT_INSERT
+         * Group: oracle
+         * 
+         * @param incrementalSnapshotWatermarkingStrategy the value to set
+         * @return the dsl builder
+         */
+        default DebeziumOracleComponentBuilder incrementalSnapshotWatermarkingStrategy(
+                java.lang.String incrementalSnapshotWatermarkingStrategy) {
+            doSetProperty("incrementalSnapshotWatermarkingStrategy", incrementalSnapshotWatermarkingStrategy);
+            return this;
+        }
         /**
          * Specify how INTERVAL columns should be represented in change events,
          * including: 'string' represents values as an exact ISO formatted
@@ -1445,6 +1465,22 @@ public interface DebeziumOracleComponentBuilderFactory {
             doSetProperty("pollIntervalMs", pollIntervalMs);
             return this;
         }
+        /**
+         * Optional list of post processors. The processors are defined using
+         * '.type' config option and configured using options ''.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: oracle
+         * 
+         * @param postProcessors the value to set
+         * @return the dsl builder
+         */
+        default DebeziumOracleComponentBuilder postProcessors(
+                java.lang.String postProcessors) {
+            doSetProperty("postProcessors", postProcessors);
+            return this;
+        }
         /**
          * Enables transaction metadata extraction together with event counting.
          * 
@@ -2109,6 +2145,7 @@ public interface DebeziumOracleComponentBuilderFactory {
             case "heartbeatTopicsPrefix": getOrCreateConfiguration((DebeziumOracleComponent) component).setHeartbeatTopicsPrefix((java.lang.String) value); return true;
             case "includeSchemaChanges": getOrCreateConfiguration((DebeziumOracleComponent) component).setIncludeSchemaChanges((boolean) value); return true;
             case "includeSchemaComments": getOrCreateConfiguration((DebeziumOracleComponent) component).setIncludeSchemaComments((boolean) value); return true;
+            case "incrementalSnapshotWatermarkingStrategy": getOrCreateConfiguration((DebeziumOracleComponent) component).setIncrementalSnapshotWatermarkingStrategy((java.lang.String) value); return true;
             case "intervalHandlingMode": getOrCreateConfiguration((DebeziumOracleComponent) component).setIntervalHandlingMode((java.lang.String) value); return true;
             case "lobEnabled": getOrCreateConfiguration((DebeziumOracleComponent) component).setLobEnabled((boolean) value); return true;
             case "logMiningArchiveDestinationName": getOrCreateConfiguration((DebeziumOracleComponent) component).setLogMiningArchiveDestinationName((java.lang.String) value); return true;
@@ -2150,6 +2187,7 @@ public interface DebeziumOracleComponentBuilderFactory {
             case "openlogreplicatorPort": getOrCreateConfiguration((DebeziumOracleComponent) component).setOpenlogreplicatorPort((int) value); return true;
             case "openlogreplicatorSource": getOrCreateConfiguration((DebeziumOracleComponent) component).setOpenlogreplicatorSource((java.lang.String) value); return true;
             case "pollIntervalMs": getOrCreateConfiguration((DebeziumOracleComponent) component).setPollIntervalMs((long) value); return true;
+            case "postProcessors": getOrCreateConfiguration((DebeziumOracleComponent) component).setPostProcessors((java.lang.String) value); return true;
             case "provideTransactionMetadata": getOrCreateConfiguration((DebeziumOracleComponent) component).setProvideTransactionMetadata((boolean) value); return true;
             case "queryFetchSize": getOrCreateConfiguration((DebeziumOracleComponent) component).setQueryFetchSize((int) value); return true;
             case "racNodes": getOrCreateConfiguration((DebeziumOracleComponent) component).setRacNodes((java.lang.String) value); return true;
diff --git a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumPostgresComponentBuilderFactory.java b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumPostgresComponentBuilderFactory.java
index 3deb28749a7..61ba5853076 100644
--- a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumPostgresComponentBuilderFactory.java
+++ b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumPostgresComponentBuilderFactory.java
@@ -853,6 +853,26 @@ public interface DebeziumPostgresComponentBuilderFactory {
             doSetProperty("incrementalSnapshotChunkSize", incrementalSnapshotChunkSize);
             return this;
         }
+        /**
+         * Specify the strategy used for watermarking during an incremental
+         * snapshot: 'insert_insert' both open and close signal is written into
+         * signal data collection (default); 'insert_delete' only open signal is
+         * written on signal data collection, the close will delete the relative
+         * open signal;.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Default: INSERT_INSERT
+         * Group: postgres
+         * 
+         * @param incrementalSnapshotWatermarkingStrategy the value to set
+         * @return the dsl builder
+         */
+        default DebeziumPostgresComponentBuilder incrementalSnapshotWatermarkingStrategy(
+                java.lang.String incrementalSnapshotWatermarkingStrategy) {
+            doSetProperty("incrementalSnapshotWatermarkingStrategy", incrementalSnapshotWatermarkingStrategy);
+            return this;
+        }
         /**
          * Specify how INTERVAL columns should be represented in change events,
          * including: 'string' represents values as an exact ISO formatted
@@ -1044,6 +1064,22 @@ public interface DebeziumPostgresComponentBuilderFactory {
             doSetProperty("pollIntervalMs", pollIntervalMs);
             return this;
         }
+        /**
+         * Optional list of post processors. The processors are defined using
+         * '.type' config option and configured using options ''.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: postgres
+         * 
+         * @param postProcessors the value to set
+         * @return the dsl builder
+         */
+        default DebeziumPostgresComponentBuilder postProcessors(
+                java.lang.String postProcessors) {
+            doSetProperty("postProcessors", postProcessors);
+            return this;
+        }
         /**
          * Enables transaction metadata extraction together with event counting.
          * 
@@ -1876,6 +1912,7 @@ public interface DebeziumPostgresComponentBuilderFactory {
             case "includeSchemaComments": getOrCreateConfiguration((DebeziumPostgresComponent) component).setIncludeSchemaComments((boolean) value); return true;
             case "includeUnknownDatatypes": getOrCreateConfiguration((DebeziumPostgresComponent) component).setIncludeUnknownDatatypes((boolean) value); return true;
             case "incrementalSnapshotChunkSize": getOrCreateConfiguration((DebeziumPostgresComponent) component).setIncrementalSnapshotChunkSize((int) value); return true;
+            case "incrementalSnapshotWatermarkingStrategy": getOrCreateConfiguration((DebeziumPostgresComponent) component).setIncrementalSnapshotWatermarkingStrategy((java.lang.String) value); return true;
             case "intervalHandlingMode": getOrCreateConfiguration((DebeziumPostgresComponent) component).setIntervalHandlingMode((java.lang.String) value); return true;
             case "maxBatchSize": getOrCreateConfiguration((DebeziumPostgresComponent) component).setMaxBatchSize((int) value); return true;
             case "maxQueueSize": getOrCreateConfiguration((DebeziumPostgresComponent) component).setMaxQueueSize((int) value); return true;
@@ -1887,6 +1924,7 @@ public interface DebeziumPostgresComponentBuilderFactory {
             case "notificationSinkTopicName": getOrCreateConfiguration((DebeziumPostgresComponent) component).setNotificationSinkTopicName((java.lang.String) value); return true;
             case "pluginName": getOrCreateConfiguration((DebeziumPostgresComponent) component).setPluginName((java.lang.String) value); return true;
             case "pollIntervalMs": getOrCreateConfiguration((DebeziumPostgresComponent) component).setPollIntervalMs((long) value); return true;
+            case "postProcessors": getOrCreateConfiguration((DebeziumPostgresComponent) component).setPostProcessors((java.lang.String) value); return true;
             case "provideTransactionMetadata": getOrCreateConfiguration((DebeziumPostgresComponent) component).setProvideTransactionMetadata((boolean) value); return true;
             case "publicationAutocreateMode": getOrCreateConfiguration((DebeziumPostgresComponent) component).setPublicationAutocreateMode((java.lang.String) value); return true;
             case "publicationName": getOrCreateConfiguration((DebeziumPostgresComponent) component).setPublicationName((java.lang.String) value); return true;
diff --git a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumSqlserverComponentBuilderFactory.java b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumSqlserverComponentBuilderFactory.java
index 34f9b4811d3..2b56a0da531 100644
--- a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumSqlserverComponentBuilderFactory.java
+++ b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumSqlserverComponentBuilderFactory.java
@@ -731,6 +731,26 @@ public interface DebeziumSqlserverComponentBuilderFactory {
             doSetProperty("incrementalSnapshotOptionRecompile", incrementalSnapshotOptionRecompile);
             return this;
         }
+        /**
+         * Specify the strategy used for watermarking during an incremental
+         * snapshot: 'insert_insert' both open and close signal is written into
+         * signal data collection (default); 'insert_delete' only open signal is
+         * written on signal data collection, the close will delete the relative
+         * open signal;.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Default: INSERT_INSERT
+         * Group: sqlserver
+         * 
+         * @param incrementalSnapshotWatermarkingStrategy the value to set
+         * @return the dsl builder
+         */
+        default DebeziumSqlserverComponentBuilder incrementalSnapshotWatermarkingStrategy(
+                java.lang.String incrementalSnapshotWatermarkingStrategy) {
+            doSetProperty("incrementalSnapshotWatermarkingStrategy", incrementalSnapshotWatermarkingStrategy);
+            return this;
+        }
         /**
          * Maximum size of each batch of source records. Defaults to 2048.
          * 
@@ -870,6 +890,22 @@ public interface DebeziumSqlserverComponentBuilderFactory {
             doSetProperty("pollIntervalMs", pollIntervalMs);
             return this;
         }
+        /**
+         * Optional list of post processors. The processors are defined using
+         * '.type' config option and configured using options ''.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: sqlserver
+         * 
+         * @param postProcessors the value to set
+         * @return the dsl builder
+         */
+        default DebeziumSqlserverComponentBuilder postProcessors(
+                java.lang.String postProcessors) {
+            doSetProperty("postProcessors", postProcessors);
+            return this;
+        }
         /**
          * Enables transaction metadata extraction together with event counting.
          * 
@@ -1485,6 +1521,7 @@ public interface DebeziumSqlserverComponentBuilderFactory {
             case "incrementalSnapshotAllowSchemaChanges": getOrCreateConfiguration((DebeziumSqlserverComponent) component).setIncrementalSnapshotAllowSchemaChanges((boolean) value); return true;
             case "incrementalSnapshotChunkSize": getOrCreateConfiguration((DebeziumSqlserverComponent) component).setIncrementalSnapshotChunkSize((int) value); return true;
             case "incrementalSnapshotOptionRecompile": getOrCreateConfiguration((DebeziumSqlserverComponent) component).setIncrementalSnapshotOptionRecompile((boolean) value); return true;
+            case "incrementalSnapshotWatermarkingStrategy": getOrCreateConfiguration((DebeziumSqlserverComponent) component).setIncrementalSnapshotWatermarkingStrategy((java.lang.String) value); return true;
             case "maxBatchSize": getOrCreateConfiguration((DebeziumSqlserverComponent) component).setMaxBatchSize((int) value); return true;
             case "maxIterationTransactions": getOrCreateConfiguration((DebeziumSqlserverComponent) component).setMaxIterationTransactions((int) value); return true;
             case "maxQueueSize": getOrCreateConfiguration((DebeziumSqlserverComponent) component).setMaxQueueSize((int) value); return true;
@@ -1493,6 +1530,7 @@ public interface DebeziumSqlserverComponentBuilderFactory {
             case "notificationEnabledChannels": getOrCreateConfiguration((DebeziumSqlserverComponent) component).setNotificationEnabledChannels((java.lang.String) value); return true;
             case "notificationSinkTopicName": getOrCreateConfiguration((DebeziumSqlserverComponent) component).setNotificationSinkTopicName((java.lang.String) value); return true;
             case "pollIntervalMs": getOrCreateConfiguration((DebeziumSqlserverComponent) component).setPollIntervalMs((long) value); return true;
+            case "postProcessors": getOrCreateConfiguration((DebeziumSqlserverComponent) component).setPostProcessors((java.lang.String) value); return true;
             case "provideTransactionMetadata": getOrCreateConfiguration((DebeziumSqlserverComponent) component).setProvideTransactionMetadata((boolean) value); return true;
             case "retriableRestartConnectorWaitMs": getOrCreateConfiguration((DebeziumSqlserverComponent) component).setRetriableRestartConnectorWaitMs((long) value); return true;
             case "schemaHistoryInternal": getOrCreateConfiguration((DebeziumSqlserverComponent) component).setSchemaHistoryInternal((java.lang.String) value); return true;
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/CloudtrailEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/CloudtrailEndpointBuilderFactory.java
index 545c1347d6c..44ec8e0d4e5 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/CloudtrailEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/CloudtrailEndpointBuilderFactory.java
@@ -1099,6 +1099,19 @@ public interface CloudtrailEndpointBuilderFactory {
     }
 
     public interface CloudtrailBuilders {
+        /**
+         * AWS Cloudtrail (camel-aws-cloudtrail)
+         * Consume events from Amazon Cloudtrail using AWS SDK version 2.x.
+         * 
+         * Category: cloud,management,monitoring
+         * Since: 3.19
+         * Maven coordinates: org.apache.camel:camel-aws-cloudtrail
+         * 
+         * @return the dsl builder for the headers' name.
+         */
+        default CloudtrailHeaderNameBuilder awsCloudtrail() {
+            return CloudtrailHeaderNameBuilder.INSTANCE;
+        }
         /**
          * AWS Cloudtrail (camel-aws-cloudtrail)
          * Consume events from Amazon Cloudtrail using AWS SDK version 2.x.
@@ -1142,6 +1155,70 @@ public interface CloudtrailEndpointBuilderFactory {
             return CloudtrailEndpointBuilderFactory.endpointBuilder(componentName, path);
         }
     }
+
+    /**
+     * The builder of headers' name for the AWS Cloudtrail component.
+     */
+    public static class CloudtrailHeaderNameBuilder {
+        /**
+         * The internal instance of the builder used to access to all the
+         * methods representing the name of headers.
+         */
+        private static final CloudtrailHeaderNameBuilder INSTANCE = new CloudtrailHeaderNameBuilder();
+
+        /**
+         * The event ID of the cloud trail event consumed.
+         * 
+         * The option is a: {@code String} type.
+         * 
+         * Group: consumer
+         * 
+         * @return the name of the header {@code AwsCloudTrailEventId}.
+         */
+        public String awsCloudTrailEventId() {
+            return "CamelAwsCloudTrailEventId";
+        }
+
+        /**
+         * The event Name of the cloud trail event consumed.
+         * 
+         * The option is a: {@code String} type.
+         * 
+         * Group: consumer
+         * 
+         * @return the name of the header {@code AwsCloudTrailEventName}.
+         */
+        public String awsCloudTrailEventName() {
+            return "CamelAwsCloudTrailEventName";
+        }
+
+        /**
+         * The event Source of the cloud trail event consumed.
+         * 
+         * The option is a: {@code String} type.
+         * 
+         * Group: consumer
+         * 
+         * @return the name of the header {@code AwsCloudTrailEventSource}.
+         */
+        public String awsCloudTrailEventSource() {
+            return "CamelAwsCloudTrailEventSource";
+        }
+
+        /**
+         * The associated username of the event of the cloud trail event
+         * consumed.
+         * 
+         * The option is a: {@code String} type.
+         * 
+         * Group: consumer
+         * 
+         * @return the name of the header {@code AwsCloudTrailEventUsername}.
+         */
+        public String awsCloudTrailEventUsername() {
+            return "CamelAwsCloudTrailEventUsername";
+        }
+    }
     static CloudtrailEndpointBuilder endpointBuilder(
             String componentName,
             String path) {
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumDb2EndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumDb2EndpointBuilderFactory.java
index 5f9fdb5fa40..2e3ddaa7a62 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumDb2EndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumDb2EndpointBuilderFactory.java
@@ -729,6 +729,26 @@ public interface DebeziumDb2EndpointBuilderFactory {
             doSetProperty("incrementalSnapshotChunkSize", incrementalSnapshotChunkSize);
             return this;
         }
+        /**
+         * Specify the strategy used for watermarking during an incremental
+         * snapshot: 'insert_insert' both open and close signal is written into
+         * signal data collection (default); 'insert_delete' only open signal is
+         * written on signal data collection, the close will delete the relative
+         * open signal;.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Default: INSERT_INSERT
+         * Group: db2
+         * 
+         * @param incrementalSnapshotWatermarkingStrategy the value to set
+         * @return the dsl builder
+         */
+        default DebeziumDb2EndpointBuilder incrementalSnapshotWatermarkingStrategy(
+                String incrementalSnapshotWatermarkingStrategy) {
+            doSetProperty("incrementalSnapshotWatermarkingStrategy", incrementalSnapshotWatermarkingStrategy);
+            return this;
+        }
         /**
          * Maximum size of each batch of source records. Defaults to 2048.
          * 
@@ -915,6 +935,21 @@ public interface DebeziumDb2EndpointBuilderFactory {
             doSetProperty("pollIntervalMs", pollIntervalMs);
             return this;
         }
+        /**
+         * Optional list of post processors. The processors are defined using
+         * '.type' config option and configured using options ''.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: db2
+         * 
+         * @param postProcessors the value to set
+         * @return the dsl builder
+         */
+        default DebeziumDb2EndpointBuilder postProcessors(String postProcessors) {
+            doSetProperty("postProcessors", postProcessors);
+            return this;
+        }
         /**
          * Enables transaction metadata extraction together with event counting.
          * 
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumMongodbEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumMongodbEndpointBuilderFactory.java
index 1f707e326af..72e9176c7c2 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumMongodbEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumMongodbEndpointBuilderFactory.java
@@ -620,6 +620,26 @@ public interface DebeziumMongodbEndpointBuilderFactory {
             doSetProperty("heartbeatTopicsPrefix", heartbeatTopicsPrefix);
             return this;
         }
+        /**
+         * Specify the strategy used for watermarking during an incremental
+         * snapshot: 'insert_insert' both open and close signal is written into
+         * signal data collection (default); 'insert_delete' only open signal is
+         * written on signal data collection, the close will delete the relative
+         * open signal;.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Default: INSERT_INSERT
+         * Group: mongodb
+         * 
+         * @param incrementalSnapshotWatermarkingStrategy the value to set
+         * @return the dsl builder
+         */
+        default DebeziumMongodbEndpointBuilder incrementalSnapshotWatermarkingStrategy(
+                String incrementalSnapshotWatermarkingStrategy) {
+            doSetProperty("incrementalSnapshotWatermarkingStrategy", incrementalSnapshotWatermarkingStrategy);
+            return this;
+        }
         /**
          * Maximum size of each batch of source records. Defaults to 2048.
          * 
@@ -738,13 +758,13 @@ public interface DebeziumMongodbEndpointBuilderFactory {
         }
         /**
          * The method used to connect to MongoDB cluster. Options include:
-         * 'replica_set' (the default) to individually connect to each replica
-         * set / shard 'sharded' to connect via single connection obtained from
-         * connection string.
+         * 'replica_set' to individually connect to each replica set / shard
+         * 'sharded' (the default) to connect via single connection obtained
+         * from connection string.
          * 
          * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
          * 
-         * Default: replica_set
+         * Default: sharded
          * Group: mongodb
          * 
          * @param mongodbConnectionMode the value to set
@@ -1101,6 +1121,22 @@ public interface DebeziumMongodbEndpointBuilderFactory {
             doSetProperty("pollIntervalMs", pollIntervalMs);
             return this;
         }
+        /**
+         * Optional list of post processors. The processors are defined using
+         * '.type' config option and configured using options ''.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: mongodb
+         * 
+         * @param postProcessors the value to set
+         * @return the dsl builder
+         */
+        default DebeziumMongodbEndpointBuilder postProcessors(
+                String postProcessors) {
+            doSetProperty("postProcessors", postProcessors);
+            return this;
+        }
         /**
          * Enables transaction metadata extraction together with event counting.
          * 
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumOracleEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumOracleEndpointBuilderFactory.java
index ea9335d5a02..33951be875a 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumOracleEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumOracleEndpointBuilderFactory.java
@@ -841,6 +841,26 @@ public interface DebeziumOracleEndpointBuilderFactory {
             doSetProperty("includeSchemaComments", includeSchemaComments);
             return this;
         }
+        /**
+         * Specify the strategy used for watermarking during an incremental
+         * snapshot: 'insert_insert' both open and close signal is written into
+         * signal data collection (default); 'insert_delete' only open signal is
+         * written on signal data collection, the close will delete the relative
+         * open signal;.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Default: INSERT_INSERT
+         * Group: oracle
+         * 
+         * @param incrementalSnapshotWatermarkingStrategy the value to set
+         * @return the dsl builder
+         */
+        default DebeziumOracleEndpointBuilder incrementalSnapshotWatermarkingStrategy(
+                String incrementalSnapshotWatermarkingStrategy) {
+            doSetProperty("incrementalSnapshotWatermarkingStrategy", incrementalSnapshotWatermarkingStrategy);
+            return this;
+        }
         /**
          * Specify how INTERVAL columns should be represented in change events,
          * including: 'string' represents values as an exact ISO formatted
@@ -1978,6 +1998,22 @@ public interface DebeziumOracleEndpointBuilderFactory {
             doSetProperty("pollIntervalMs", pollIntervalMs);
             return this;
         }
+        /**
+         * Optional list of post processors. The processors are defined using
+         * '.type' config option and configured using options ''.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: oracle
+         * 
+         * @param postProcessors the value to set
+         * @return the dsl builder
+         */
+        default DebeziumOracleEndpointBuilder postProcessors(
+                String postProcessors) {
+            doSetProperty("postProcessors", postProcessors);
+            return this;
+        }
         /**
          * Enables transaction metadata extraction together with event counting.
          * 
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumPostgresEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumPostgresEndpointBuilderFactory.java
index 765af28e270..804381663f6 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumPostgresEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumPostgresEndpointBuilderFactory.java
@@ -1023,6 +1023,26 @@ public interface DebeziumPostgresEndpointBuilderFactory {
             doSetProperty("incrementalSnapshotChunkSize", incrementalSnapshotChunkSize);
             return this;
         }
+        /**
+         * Specify the strategy used for watermarking during an incremental
+         * snapshot: 'insert_insert' both open and close signal is written into
+         * signal data collection (default); 'insert_delete' only open signal is
+         * written on signal data collection, the close will delete the relative
+         * open signal;.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Default: INSERT_INSERT
+         * Group: postgres
+         * 
+         * @param incrementalSnapshotWatermarkingStrategy the value to set
+         * @return the dsl builder
+         */
+        default DebeziumPostgresEndpointBuilder incrementalSnapshotWatermarkingStrategy(
+                String incrementalSnapshotWatermarkingStrategy) {
+            doSetProperty("incrementalSnapshotWatermarkingStrategy", incrementalSnapshotWatermarkingStrategy);
+            return this;
+        }
         /**
          * Specify how INTERVAL columns should be represented in change events,
          * including: 'string' represents values as an exact ISO formatted
@@ -1280,6 +1300,22 @@ public interface DebeziumPostgresEndpointBuilderFactory {
             doSetProperty("pollIntervalMs", pollIntervalMs);
             return this;
         }
+        /**
+         * Optional list of post processors. The processors are defined using
+         * '.type' config option and configured using options ''.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: postgres
+         * 
+         * @param postProcessors the value to set
+         * @return the dsl builder
+         */
+        default DebeziumPostgresEndpointBuilder postProcessors(
+                String postProcessors) {
+            doSetProperty("postProcessors", postProcessors);
+            return this;
+        }
         /**
          * Enables transaction metadata extraction together with event counting.
          * 
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumSqlserverEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumSqlserverEndpointBuilderFactory.java
index 7702d06ef84..fd0e707f344 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumSqlserverEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumSqlserverEndpointBuilderFactory.java
@@ -912,6 +912,26 @@ public interface DebeziumSqlserverEndpointBuilderFactory {
             doSetProperty("incrementalSnapshotOptionRecompile", incrementalSnapshotOptionRecompile);
             return this;
         }
+        /**
+         * Specify the strategy used for watermarking during an incremental
+         * snapshot: 'insert_insert' both open and close signal is written into
+         * signal data collection (default); 'insert_delete' only open signal is
+         * written on signal data collection, the close will delete the relative
+         * open signal;.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Default: INSERT_INSERT
+         * Group: sqlserver
+         * 
+         * @param incrementalSnapshotWatermarkingStrategy the value to set
+         * @return the dsl builder
+         */
+        default DebeziumSqlserverEndpointBuilder incrementalSnapshotWatermarkingStrategy(
+                String incrementalSnapshotWatermarkingStrategy) {
+            doSetProperty("incrementalSnapshotWatermarkingStrategy", incrementalSnapshotWatermarkingStrategy);
+            return this;
+        }
         /**
          * Maximum size of each batch of source records. Defaults to 2048.
          * 
@@ -1138,6 +1158,22 @@ public interface DebeziumSqlserverEndpointBuilderFactory {
             doSetProperty("pollIntervalMs", pollIntervalMs);
             return this;
         }
+        /**
+         * Optional list of post processors. The processors are defined using
+         * '.type' config option and configured using options ''.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: sqlserver
+         * 
+         * @param postProcessors the value to set
+         * @return the dsl builder
+         */
+        default DebeziumSqlserverEndpointBuilder postProcessors(
+                String postProcessors) {
+            doSetProperty("postProcessors", postProcessors);
+            return this;
+        }
         /**
          * Enables transaction metadata extraction together with event counting.
          *
diff --git a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumMysqlComponentBuilderFactory.java b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumMysqlComponentBuilderFactory.java
index b1a81a17304..853e8f1d170 100644
--- a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumMysqlComponentBuilderFactory.java
+++ b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/DebeziumMysqlComponentBuilderFactory.java
@@ -448,6 +448,22 @@ public interface DebeziumMysqlComponentBuilderFactory {
             doSetProperty("connectKeepAliveIntervalMs", connectKeepAliveIntervalMs);
             return this;
         }
+        /**
+         * Specifies the connection adapter to be used.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Default: mysql
+         * Group: mysql
+         * 
+         * @param connectorAdapter the value to set
+         * @return the dsl builder
+         */
+        default DebeziumMysqlComponentBuilder connectorAdapter(
+                java.lang.String connectorAdapter) {
+            doSetProperty("connectorAdapter", connectorAdapter);
+            return this;
+        }
         /**
          * Maximum time to wait after trying to connect to the database before
          * timing out, given in milliseconds. Defaults to 30 seconds (30,000
@@ -982,11 +998,12 @@ public interface DebeziumMysqlComponentBuilderFactory {
         /**
          * Whether the connector should include the original SQL query that
          * generated the change event. Note: This option requires MySQL be
          * configured with the binlog_rows_query_log_events option set to ON.
          * Query will not be present for events generated from snapshot.
          * WARNING: Enabling this option may expose tables or fields explicitly
          * excluded or masked by including the original SQL statement in the
          * change event. For this reason the default value is 'false'.
          * 
          * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
          * 
@@ -1105,6 +1122,26 @@ public interface DebeziumMysqlComponentBuilderFactory {
             doSetProperty("incrementalSnapshotChunkSize", incrementalSnapshotChunkSize);
             return this;
         }
+        /**
+         * Specify the strategy used for watermarking during an incremental
+         * snapshot: 'insert_insert' both open and close signal is written into
+         * signal data collection (default); 'insert_delete' only open signal is
+         * written on signal data collection, the close will delete the relative
+         * open signal;.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Default: INSERT_INSERT
+         * Group: mysql
+         * 
+         * @param incrementalSnapshotWatermarkingStrategy the value to set
+         * @return the dsl builder
+         */
+        default DebeziumMysqlComponentBuilder incrementalSnapshotWatermarkingStrategy(
+                java.lang.String incrementalSnapshotWatermarkingStrategy) {
+            doSetProperty("incrementalSnapshotWatermarkingStrategy", incrementalSnapshotWatermarkingStrategy);
+            return this;
+        }
         /**
          * Maximum size of each batch of source records. Defaults to 2048.
          * 
@@ -1244,6 +1281,22 @@ public interface DebeziumMysqlComponentBuilderFactory {
             doSetProperty("pollIntervalMs", pollIntervalMs);
             return this;
         }
+        /**
+         * Optional list of post processors. The processors are defined using
+         * '.type' config option and configured using options ''.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: mysql
+         * 
+         * @param postProcessors the value to set
+         * @return the dsl builder
+         */
+        default DebeziumMysqlComponentBuilder postProcessors(
+                java.lang.String postProcessors) {
+            doSetProperty("postProcessors", postProcessors);
+            return this;
+        }
         /**
          * Enables transaction metadata extraction together with event counting.
          * 
@@ -1894,6 +1947,7 @@ public interface DebeziumMysqlComponentBuilderFactory {
             case "columnPropagateSourceType": getOrCreateConfiguration((DebeziumMySqlComponent) component).setColumnPropagateSourceType((java.lang.String) value); return true;
             case "connectKeepAlive": getOrCreateConfiguration((DebeziumMySqlComponent) component).setConnectKeepAlive((boolean) value); return true;
             case "connectKeepAliveIntervalMs": getOrCreateConfiguration((DebeziumMySqlComponent) component).setConnectKeepAliveIntervalMs((long) value); return true;
+            case "connectorAdapter": getOrCreateConfiguration((DebeziumMySqlComponent) component).setConnectorAdapter((java.lang.String) value); return true;
             case "connectTimeoutMs": getOrCreateConfiguration((DebeziumMySqlComponent) component).setConnectTimeoutMs((int) value); return true;
             case "converters": getOrCreateConfiguration((DebeziumMySqlComponent) component).setConverters((java.lang.String) value); return true;
             case "customMetricTags": getOrCreateConfiguration((DebeziumMySqlComponent) component).setCustomMetricTags((java.lang.String) value); return true;
@@ -1930,6 +1984,7 @@ public interface DebeziumMysqlComponentBuilderFactory {
             case "inconsistentSchemaHandlingMode": getOrCreateConfiguration((DebeziumMySqlComponent) component).setInconsistentSchemaHandlingMode((java.lang.String) value); return true;
             case "incrementalSnapshotAllowSchemaChanges": getOrCreateConfiguration((DebeziumMySqlComponent) component).setIncrementalSnapshotAllowSchemaChanges((boolean) value); return true;
             case "incrementalSnapshotChunkSize": getOrCreateConfiguration((DebeziumMySqlComponent) component).setIncrementalSnapshotChunkSize((int) value); return true;
+            case "incrementalSnapshotWatermarkingStrategy": getOrCreateConfiguration((DebeziumMySqlComponent) component).setIncrementalSnapshotWatermarkingStrategy((java.lang.String) value); return true;
             case "maxBatchSize": getOrCreateConfiguration((DebeziumMySqlComponent) component).setMaxBatchSize((int) value); return true;
             case "maxQueueSize": getOrCreateConfiguration((DebeziumMySqlComponent) component).setMaxQueueSize((int) value); return true;
             case "maxQueueSizeInBytes": getOrCreateConfiguration((DebeziumMySqlComponent) component).setMaxQueueSizeInBytes((long) value); return true;
@@ -1938,6 +1993,7 @@ public interface DebeziumMysqlComponentBuilderFactory {
             case "notificationEnabledChannels": getOrCreateConfiguration((DebeziumMySqlComponent) component).setNotificationEnabledChannels((java.lang.String) value); return true;
             case "notificationSinkTopicName": getOrCreateConfiguration((DebeziumMySqlComponent) component).setNotificationSinkTopicName((java.lang.String) value); return true;
             case "pollIntervalMs": getOrCreateConfiguration((DebeziumMySqlComponent) component).setPollIntervalMs((long) value); return true;
+            case "postProcessors": getOrCreateConfiguration((DebeziumMySqlComponent) component).setPostProcessors((java.lang.String) value); return true;
             case "provideTransactionMetadata": getOrCreateConfiguration((DebeziumMySqlComponent) component).setProvideTransactionMetadata((boolean) value); return true;
             case "queryFetchSize": getOrCreateConfiguration((DebeziumMySqlComponent) component).setQueryFetchSize((int) value); return true;
             case "retriableRestartConnectorWaitMs": getOrCreateConfiguration((DebeziumMySqlComponent) component).setRetriableRestartConnectorWaitMs((long) value); return true;
@@ -982,11 +998,12 @@ public interface DebeziumMysqlComponentBuilderFactory {
          * Whether the connector should include the original SQL query that
          * generated the change event. Note: This option requires MySQL be
-         * configured with the binlog_rows_query_log_events option set to ON.
-         * Query will not be present for events generated from snapshot.
-         * WARNING: Enabling this option may expose tables or fields explicitly
-         * excluded or masked by including the original SQL statement in the
-         * change event. For this reason the default value is 'false'.
+         * configured with the binlog_rows_query_log_events option set to ON. If
+         * using MariaDB, configure the binlog_annotate_row_events option must
+         * be set to ON. Query will not be present for events generated from
+         * snapshot. WARNING: Enabling this option may expose tables or fields
+         * explicitly excluded or masked by including the original SQL statement
+         * in the change event. For this reason the default value is 'false'.
          * 
          * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumMySqlEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumMySqlEndpointBuilderFactory.java
index c133c34da13..57181364e4a 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumMySqlEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/DebeziumMySqlEndpointBuilderFactory.java
@@ -526,6 +526,22 @@ public interface DebeziumMySqlEndpointBuilderFactory {
             doSetProperty("connectKeepAliveIntervalMs", connectKeepAliveIntervalMs);
             return this;
         }
+        /**
+         * Specifies the connection adapter to be used.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Default: mysql
+         * Group: mysql
+         * 
+         * @param connectorAdapter the value to set
+         * @return the dsl builder
+         */
+        default DebeziumMySqlEndpointBuilder connectorAdapter(
+                String connectorAdapter) {
+            doSetProperty("connectorAdapter", connectorAdapter);
+            return this;
+        }
         /**
          * Maximum time to wait after trying to connect to the database before
          * timing out, given in milliseconds. Defaults to 30 seconds (30,000
@@ -1204,11 +1220,12 @@ public interface DebeziumMySqlEndpointBuilderFactory {
         /**
          * Whether the connector should include the original SQL query that
          * generated the change event. Note: This option requires MySQL be
          * configured with the binlog_rows_query_log_events option set to ON.
          * Query will not be present for events generated from snapshot.
          * WARNING: Enabling this option may expose tables or fields explicitly
          * excluded or masked by including the original SQL statement in the
          * change event. For this reason the default value is 'false'.
          * 
          * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
          * 
@@ -1225,11 +1242,12 @@ public interface DebeziumMySqlEndpointBuilderFactory {
         /**
          * Whether the connector should include the original SQL query that
          * generated the change event. Note: This option requires MySQL be
          * configured with the binlog_rows_query_log_events option set to ON.
          * Query will not be present for events generated from snapshot.
          * WARNING: Enabling this option may expose tables or fields explicitly
          * excluded or masked by including the original SQL statement in the
          * change event. For this reason the default value is 'false'.
          * 
          * The option will be converted to a &lt;code&gt;boolean&lt;/code&gt;
          * type.
@@ -1435,6 +1453,26 @@ public interface DebeziumMySqlEndpointBuilderFactory {
             doSetProperty("incrementalSnapshotChunkSize", incrementalSnapshotChunkSize);
             return this;
         }
+        /**
+         * Specify the strategy used for watermarking during an incremental
+         * snapshot: 'insert_insert' both open and close signal is written into
+         * signal data collection (default); 'insert_delete' only open signal is
+         * written on signal data collection, the close will delete the relative
+         * open signal;.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Default: INSERT_INSERT
+         * Group: mysql
+         * 
+         * @param incrementalSnapshotWatermarkingStrategy the value to set
+         * @return the dsl builder
+         */
+        default DebeziumMySqlEndpointBuilder incrementalSnapshotWatermarkingStrategy(
+                String incrementalSnapshotWatermarkingStrategy) {
+            doSetProperty("incrementalSnapshotWatermarkingStrategy", incrementalSnapshotWatermarkingStrategy);
+            return this;
+        }
         /**
          * Maximum size of each batch of source records. Defaults to 2048.
          * 
@@ -1660,6 +1698,22 @@ public interface DebeziumMySqlEndpointBuilderFactory {
             doSetProperty("pollIntervalMs", pollIntervalMs);
             return this;
         }
+        /**
+         * Optional list of post processors. The processors are defined using
+         * '.type' config option and configured using options ''.
+         * 
+         * The option is a: &lt;code&gt;java.lang.String&lt;/code&gt; type.
+         * 
+         * Group: mysql
+         * 
+         * @param postProcessors the value to set
+         * @return the dsl builder
+         */
+        default DebeziumMySqlEndpointBuilder postProcessors(
+                String postProcessors) {
+            doSetProperty("postProcessors", postProcessors);
+            return this;
+        }
         /**
          * Enables transaction metadata extraction together with event counting.
          * 
@@ -1204,11 +1220,12 @@ public interface DebeziumMySqlEndpointBuilderFactory {
          * Whether the connector should include the original SQL query that
          * generated the change event. Note: This option requires MySQL be
-         * configured with the binlog_rows_query_log_events option set to ON.
-         * Query will not be present for events generated from snapshot.
-         * WARNING: Enabling this option may expose tables or fields explicitly
-         * excluded or masked by including the original SQL statement in the
-         * change event. For this reason the default value is 'false'.
+         * configured with the binlog_rows_query_log_events option set to ON. If
+         * using MariaDB, configure the binlog_annotate_row_events option must
+         * be set to ON. Query will not be present for events generated from
+         * snapshot. WARNING: Enabling this option may expose tables or fields
+         * explicitly excluded or masked by including the original SQL statement
+         * in the change event. For this reason the default value is 'false'.
          * 
          * The option is a: &lt;code&gt;boolean&lt;/code&gt; type.
@@ -1225,11 +1242,12 @@ public interface DebeziumMySqlEndpointBuilderFactory {
          * Whether the connector should include the original SQL query that
          * generated the change event. Note: This option requires MySQL be
-         * configured with the binlog_rows_query_log_events option set to ON.
-         * Query will not be present for events generated from snapshot.
-         * WARNING: Enabling this option may expose tables or fields explicitly
-         * excluded or masked by including the original SQL statement in the
-         * change event. For this reason the default value is 'false'.
+         * configured with the binlog_rows_query_log_events option set to ON. If
+         * using MariaDB, configure the binlog_annotate_row_events option must
+         * be set to ON. Query will not be present for events generated from
+         * snapshot. WARNING: Enabling this option may expose tables or fields
+         * explicitly excluded or masked by including the original SQL statement
+         * in the change event. For this reason the default value is 'false'.
          * 
          * The option will be converted to a &lt;code&gt;boolean&lt;/code&gt;